"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importStar(require("react"));
var urql_1 = require("urql");
var builMqlUrqlClient_1 = __importDefault(require("../../utils/builMqlUrqlClient"));
var MqlServerUrlQuery_1 = __importDefault(require("../../queries/core/MqlServerUrlQuery"));
var SetMqlServer_1 = __importDefault(require("../../mutations/core/SetMqlServer"));
var MqlContext_1 = __importStar(require("./MqlContext"));
/*
  This thin wrapper allows us to use an urql Provider to provide access to our Core API
  for the sake of interacting with MQL Server and Model Key selection
*/
function MqlContextProvider(_a) {
    var getToken = _a.getToken, children = _a.children, isAuthenticated = _a.isAuthenticated, captureException = _a.captureException;
    var coreApiClient = builMqlUrqlClient_1.default(getToken, MqlContext_1.CORE_API_URL);
    return (react_1.default.createElement(urql_1.Provider, { value: coreApiClient },
        react_1.default.createElement(MqlContextProviderInternal, { isAuthenticated: isAuthenticated, getToken: getToken, captureException: captureException }, children)));
}
function MqlContextProviderInternal(_a) {
    var getToken = _a.getToken, isAuthenticated = _a.isAuthenticated, children = _a.children, captureException = _a.captureException;
    // We do this because we want to allow the parent to provide a bespoke error handling function.
    var handleCombinedError = react_1.useCallback(function (e) {
        var errFunction = captureException || console.error;
        if (e.message) {
            errFunction(e.message);
        }
        if (e.networkError) {
            errFunction(e.networkError);
        }
    }, [captureException]);
    /*
      Until recently, making a request to the MQL Server would require:
        1. The MQL Server URL
        2. A specific Model Key representing the model content used to execute the query
  
      Because we cannot yet specify the desired model in the UI, we would always retrieve
      and then supply the current model key. But now the MQL Server considers the Model Key
      optional. In its absense, it uses the current model.
  
      In the future, our UI will allow users to select a specific Model Key for querying,
      and at that point, we will update this code with a setModelKey mutation as we have
      for MqlServerUrl.
    */
    var _b = urql_1.useQuery({
        query: MqlServerUrlQuery_1.default,
        pause: !isAuthenticated,
    }), _c = _b[0], mqlServerUrlData = _c.data, mqlServerUrlError = _c.error, refetchMqlServerUrl = _b[1];
    if (mqlServerUrlError)
        handleCombinedError(mqlServerUrlError);
    var _d = urql_1.useMutation(SetMqlServer_1.default), fetching = _d[0].fetching, setMqlServer = _d[1];
    var setMqlServerThenRefetch = react_1.useCallback(function (newServerId) {
        // Note: newServerid is cast as a string because it is stored on the backend
        // as a User Preference, whose values are all strings.
        return setMqlServer({ newServerIdAsString: "" + newServerId }).then(refetchMqlServerUrl);
    }, [setMqlServer, refetchMqlServerUrl]);
    /*
      Note: Before the mqlServerUrl is available, an urql client will be constructed with the url set to the CORE_API_URL.
      This is because it throws an error to build an urql client without a URL.
      Naturally, this is invalid, so we must check with the mqlServerUrl is present before initiating MQL Queries.
    */
    var mqlClient = builMqlUrqlClient_1.default(getToken, (mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl) || MqlContext_1.CORE_API_URL);
    var _e = react_1.useState({
        coreApiUrl: MqlContext_1.CORE_API_URL,
        mqlServerUrl: mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl,
        setMqlServer: setMqlServerThenRefetch,
        mqlServerOverrideLoading: fetching,
        modelKey: null,
        setModelKey: function () { return Promise.resolve(); },
        modalKeyOverrideLoading: false,
        mqlClient: mqlClient,
        getToken: getToken,
        useQuery: urql_1.useQuery,
        useMutation: urql_1.useMutation,
        handleCombinedError: handleCombinedError,
    }), mqlContext = _e[0], setMqlContext = _e[1];
    react_1.useEffect(function () {
        var stateToUpdate = {};
        if ((mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl) !== mqlContext.mqlServerUrl) {
            stateToUpdate.mqlServerUrl = mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl;
        }
        if ((mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl) &&
            (mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl) !== mqlContext.mqlServerUrl) {
            stateToUpdate.mqlClient = builMqlUrqlClient_1.default(getToken, mqlServerUrlData === null || mqlServerUrlData === void 0 ? void 0 : mqlServerUrlData.mqlServerUrl);
        }
        /*
          FUTURE: Add check for Model Key.
        */
        if (Object.keys(stateToUpdate).length > 0) {
            setMqlContext(__assign(__assign({}, mqlContext), stateToUpdate));
        }
    }, [mqlServerUrlData, getToken, mqlContext]);
    return (react_1.default.createElement(urql_1.Provider, { value: mqlContext.mqlClient },
        react_1.default.createElement(MqlContext_1.default.Provider, { value: mqlContext }, children)));
}
exports.default = MqlContextProvider;
